pub struct PipelineContext<'a> { /* private fields */ }Expand description
Context passed to pipeline initialization functions.
Implementations
Sourceimpl<'a> PipelineContext<'a>
impl<'a> PipelineContext<'a>
Sourcepub fn resources(&self) -> RenderResources<'_>
pub fn resources(&self) -> RenderResources<'_>
Returns shared GPU resources used for pipeline creation.
Sourcepub fn register_draw_pipeline<T, P>(&mut self, pipeline: P)where
T: DrawCommand + 'static,
P: DrawablePipeline<T> + 'static,
pub fn register_draw_pipeline<T, P>(&mut self, pipeline: P)where
T: DrawCommand + 'static,
P: DrawablePipeline<T> + 'static,
Registers a draw pipeline for a specific command type.
Sourcepub fn register_compute_pipeline<T, P>(&mut self, pipeline: P)where
T: ComputeCommand + 'static,
P: ComputablePipeline<T> + 'static,
pub fn register_compute_pipeline<T, P>(&mut self, pipeline: P)where
T: ComputeCommand + 'static,
P: ComputablePipeline<T> + 'static,
Registers a compute pipeline for a specific command type.
Sourcepub fn register_composite_pipeline<T, P>(&mut self, pipeline: P)where
T: CompositeCommand + 'static,
P: CompositePipeline<T> + 'static,
pub fn register_composite_pipeline<T, P>(&mut self, pipeline: P)where
T: CompositeCommand + 'static,
P: CompositePipeline<T> + 'static,
Registers a composite pipeline for a specific command type.